@@ -1,27 +1,27 @@
 #' construct a corpus object
-#' 
-#' Creates a corpus object from available sources.  The currently available  
-#' sources are: 
-#' \itemize{ 
-#' \item a \link{character} vector, consisting of one document per element; if 
+#'
+#' Creates a corpus object from available sources.  The currently available
+#' sources are:
+#' \itemize{
+#' \item a \link{character} vector, consisting of one document per element; if
 #'   the elements are named, these names will be used as document names.
-#' \item a \link{data.frame}, whose default document id is a variable identified
-#' by \code{docid_field}; the text of the document is a variable identified by
-#' \code{textid_field}; and other variables are imported as document-level
-#' meta-data.  This matches the format of data.frames constructed by the the
-#' \pkg{readtext} package.
+#' \item a \link{data.frame} (or a \pkg{tibble} \code{tbl_df}), whose default
+#' document id is a variable identified by \code{docid_field}; the text of the
+#' document is a variable identified by \code{textid_field}; and other variables
+#' are imported as document-level meta-data.  This matches the format of
+#' data.frames constructed by the the \pkg{readtext} package.
 #' \item a \link{kwic} object constructed by \code{\link{kwic}}.
-#' \item a \pkg{tm} \link[tm]{VCorpus} or \link[tm]{SimpleCorpus} class  object, 
-#'   with the fixed metadata 
+#' \item a \pkg{tm} \link[tm]{VCorpus} or \link[tm]{SimpleCorpus} class  object,
+#'   with the fixed metadata
 #'   fields imported as \link{docvars} and corpus-level metadata imported
 #'   as \link{metacorpus} information.
 #' \item a \link{corpus} object.
-#' } 
+#' }
 #' @param x a valid corpus source object
-#' @param docnames Names to be assigned to the texts.  Defaults to the names of 
+#' @param docnames Names to be assigned to the texts.  Defaults to the names of
 #'   the character vector (if any); \code{doc_id} for a data.frame; the document
-#'   names in a \pkg{tm} corpus; or a vector of user-supplied labels equal in 
-#'   length to the number of documents.  If none of these are round, then 
+#'   names in a \pkg{tm} corpus; or a vector of user-supplied labels equal in
+#'   length to the number of documents.  If none of these are round, then
 #'   "text1", "text2", etc. are assigned automatically.
 #' @param docvars a data.frame of document-level variables associated with each text
 #' @param text_field the character name or numeric index of the source
@@ -33,10 +33,10 @@
 #'   to be added to the corpus as corpus-level metadata.  Special fields
 #'   recognized in the \code{\link{summary.corpus}} are:
 #' \itemize{
-#' \item{\code{source }}{a description of the source of the texts, used for 
+#' \item{\code{source }}{a description of the source of the texts, used for
 #'   referencing;}
 #' \item{\code{citation }}{information on how to cite the corpus; and}
-#' \item{\code{notes }}{any additional information about who created the text, warnings, 
+#' \item{\code{notes }}{any additional information about who created the text, warnings,
 #'   to do lists, etc.}
 #' }
 #' @param compress logical; if \code{TRUE}, compress the texts in memory using
@@ -48,29 +48,29 @@
 #'   document-level variables, document-level metadata, corpus-level metadata,
 #'   and default settings for subsequent processing of the corpus.
 #' @section A warning on accessing corpus elements: A corpus currently consists
-#'   of an S3 specially classed list of elements, but \strong{you should not 
-#'   access these elements directly}. Use the extractor and replacement 
-#'   functions instead, or else your code is not only going to be uglier, but 
-#'   also likely to break should the internal structure of a corpus object 
-#'   change (as it inevitably will as we continue to develop the package, 
+#'   of an S3 specially classed list of elements, but \strong{you should not
+#'   access these elements directly}. Use the extractor and replacement
+#'   functions instead, or else your code is not only going to be uglier, but
+#'   also likely to break should the internal structure of a corpus object
+#'   change (as it inevitably will as we continue to develop the package,
 #'   including moving corpus objects to the S4 class system).
-#' @seealso \link{corpus-class}, \code{\link{docvars}}, \code{\link{metadoc}}, 
-#'   \code{\link{metacorpus}}, 
-#'   \code{\link{settings}}, \code{\link{texts}}, \code{\link{ndoc}}, 
+#' @seealso \link{corpus-class}, \code{\link{docvars}}, \code{\link{metadoc}},
+#'   \code{\link{metacorpus}},
+#'   \code{\link{settings}}, \code{\link{texts}}, \code{\link{ndoc}},
 #'   \code{\link{docnames}}
-#' @details The texts and document variables of corpus objects can also be 
-#'   accessed using index notation. Indexing a corpus object as a vector will 
-#'   return its text, equivalent to \code{texts(x)}.  Note that this is not the 
-#'   same as subsetting the entire corpus -- this should be done using the 
+#' @details The texts and document variables of corpus objects can also be
+#'   accessed using index notation. Indexing a corpus object as a vector will
+#'   return its text, equivalent to \code{texts(x)}.  Note that this is not the
+#'   same as subsetting the entire corpus -- this should be done using the
 #'   \code{\link{subset}} method for a corpus.
-#'   
-#'   Indexing a corpus using two indexes (integers or column names) will return 
+#'
+#'   Indexing a corpus using two indexes (integers or column names) will return
 #'   the document variables, equivalent to \code{docvars(x)}.  It is also
 #'   possible to access, create, or replace docvars using list notation, e.g.
-#'   
-#'   \code{myCorpus[["newSerialDocvar"]] <- 
+#'
+#'   \code{myCorpus[["newSerialDocvar"]] <-
 #'   paste0("tag", 1:ndoc(myCorpus))}.
-#'   
+#'
 #'   For details, see \link{corpus-class}.
 #' @author Kenneth Benoit and Paul Nulty
 #' @export
@@ -78,27 +78,27 @@
 #' @examples
 #' # create a corpus from texts
 #' corpus(data_char_ukimmig2010)
-#' 
+#'
 #' # create a corpus from texts and assign meta-data and document variables
-#' summary(corpus(data_char_ukimmig2010, 
-#'                docvars = data.frame(party = names(data_char_ukimmig2010))), 5) 
+#' summary(corpus(data_char_ukimmig2010,
+#'                docvars = data.frame(party = names(data_char_ukimmig2010))), 5)
 #'
 #' corpus(texts(data_corpus_irishbudget2010))
-#' 
+#'
 #' # import a tm VCorpus
 #' if (requireNamespace("tm", quietly = TRUE)) {
 #'     data(crude, package = "tm")    # load in a tm example VCorpus
 #'     mytmCorpus <- corpus(crude)
 #'     summary(mytmCorpus, showmeta=TRUE)
-#'     
+#'
 #'     data(acq, package = "tm")
 #'     summary(corpus(acq), 5, showmeta=TRUE)
-#'     
+#'
 #'     tmCorp <- tm::VCorpus(tm::VectorSource(data_char_ukimmig2010))
 #'     quantCorp <- corpus(tmCorp)
 #'     summary(quantCorp)
 #' }
-#' 
+#'
 #' # construct a corpus from a data.frame
 #' mydf <- data.frame(letter_factor = factor(rep(letters[1:3], each = 2)),
 #'                   some_ints = 1L:6L,
@@ -106,9 +106,9 @@
 #'                   stringsAsFactors = FALSE,
 #'                   row.names = paste0("fromDf_", 1:6))
 #' mydf
-#' summary(corpus(mydf, text_field = "some_text", 
+#' summary(corpus(mydf, text_field = "some_text",
 #'                metacorpus = list(source = "From a data.frame called mydf.")))
-#' 
+#'
 #' # construct a corpus from a kwic object
 #' mykwic <- kwic(data_corpus_inaugural, "southern")
 #' summary(corpus(mykwic))
@@ -134,23 +134,23 @@ corpus.corpus <- function(x, docnames = quanteda::docnames(x), docvars = quanted
 corpus.character <- function(x, docnames = NULL, docvars = NULL, metacorpus = NULL, compress = FALSE, ...) {
     if (length(addedArgs <- list(...)))
         warning("Argument", ifelse(length(addedArgs)>1, "s ", " "), names(addedArgs), " not used.", sep = "")
-    
+
     x_names <- names(x)
-    
+
     # convert the dreaded "curly quotes" to ASCII equivalents
-    x <- stri_replace_all_fixed(x, 
+    x <- stri_replace_all_fixed(x,
                                          c("\u201C", "\u201D", "\u201F",
-                                           "\u2018", "\u201B", "\u2019"),                                     
-                                         c("\"", "\"", "\"", 
+                                           "\u2018", "\u201B", "\u2019"),
+                                         c("\"", "\"", "\"",
                                            "\'", "\'", "\'"), vectorize_all = FALSE)
-    
+
     # replace all hyphens with simple hyphen
     x <- stri_replace_all_regex(x, "\\p{Pd}", "-")
-    
+
     # normalize EOL
     x <- stri_replace_all_fixed(x, "\r\n", "\n") # Windows
     x <- stri_replace_all_fixed(x, "\r", "\n") # Old Macintosh
-    
+
     # name the texts vector
     if (!is.null(docnames)) {
         stopifnot(length(docnames) == length(x))
@@ -176,7 +176,7 @@ corpus.character <- function(x, docnames = NULL, docvars = NULL, metacorpus = NU
 
     # create the documents data frame starting with the texts, using an empty field
     # this saves space if it needs to be separated later
-    documents <- data.frame(texts = rep(NA, length(x)), 
+    documents <- data.frame(texts = rep(NA, length(x)),
                             row.names = names(x),
                             check.rows = TRUE, stringsAsFactors = FALSE)
 
@@ -185,12 +185,12 @@ corpus.character <- function(x, docnames = NULL, docvars = NULL, metacorpus = NU
         if (nrow(docvars) > 0) {
             stopifnot(nrow(docvars)==length(x))
             documents <- cbind(documents, docvars)
-        } 
+        }
     }
-    
+
     # initialize results corpus
     temp <- list()
-    
+
     ## compress and separate texts if compress == TRUE
     # paste delimiters into object to be compressed
     if (compress) {
@@ -204,18 +204,18 @@ corpus.character <- function(x, docnames = NULL, docvars = NULL, metacorpus = NU
     }
 
     # build and return the corpus object
-    temp <- c(temp, list(documents = documents, 
-                         metadata = metacorpus, 
+    temp <- c(temp, list(documents = documents,
+                         metadata = metacorpus,
                          settings = settings(),
                          tokens = NULL))
-                    
+
     ## add some elements if compress
     if (compress) {
         temp$docnames <- names(x)
         # compute the compression %
         temp$compression_rate <- utils::object.size(temp$texts) / utils::object.size(unname(x)) * 100
     }
-    
+
     class(temp) <- c("corpus", class(temp))
     if (compress) {
         class(temp) <- c("corpuszip", class(temp))
@@ -224,19 +224,20 @@ corpus.character <- function(x, docnames = NULL, docvars = NULL, metacorpus = NU
 }
 
 #' @rdname corpus
-#' @param docid_field optional column index of a document identifier; if 
-#'   \code{NULL}, the constructor will use the row.names of the data.frame (if 
+#' @param docid_field optional column index of a document identifier; if
+#'   \code{NULL}, the constructor will use the row.names of the data.frame (if
 #'   found)
 #' @keywords corpus
 #' @method corpus data.frame
 #' @export
-corpus.data.frame <- function(x, docid_field = NULL, text_field = "text", metacorpus = NULL, compress = FALSE, ...) {
-    
+corpus.data.frame <- function(x, docid_field = NULL, text_field = "text",
+                              metacorpus = NULL, compress = FALSE, ...) {
+
     if (length(addedArgs <- list(...)))
         warning("Argument", ifelse(length(addedArgs)>1, "s ", " "), names(addedArgs), " not used.", sep = "")
-    
+
     args <- list(...)
-    
+
     # text field
     if (length(text_field) != 1)
         stop("text_field must refer to a single column")
@@ -244,16 +245,16 @@ corpus.data.frame <- function(x, docid_field = NULL, text_field = "text", metaco
         if (1 <= text_field && text_field <= length(x)) {
             text_field <- names(x)[text_field]
         } else {
-            stop("text_field index refers to an invalid column") 
+            stop("text_field index refers to an invalid column")
         }
     }
     if ("docvars" %in% names(args))
         stop("docvars are assigned automatically for data.frames")
     if (!text_field %in% names(x))
         stop("column name ", text_field, " not found")
-    if (!is.character(x[, text_field, drop = TRUE]))
+    if (!is.character(x[[text_field]]))
         stop("text_field must refer to a character mode column")
-    
+
     # docname field
     if (is.null(docid_field)) {
         if (identical(row.names(x), as.character(seq_len(nrow(x))))) {
@@ -268,19 +269,19 @@ corpus.data.frame <- function(x, docid_field = NULL, text_field = "text", metaco
             if (1 <= docid_field && docid_field <= length(x)) {
                 docid_field <- names(x)[docid_field]
             } else {
-                stop("docid_field index refers to an invalid column") 
+                stop("docid_field index refers to an invalid column")
             }
         }
         if (!docid_field %in% names(x))
             stop("column name ", docid_field, " not found")
-        if (!is.character(x[, docid_field, drop = TRUE]))
+        if (!is.character(x[[docid_field]]))
             stop("docid_field must refer to a character mode column")
-        docname <- x[, docid_field, drop = TRUE]
+        docname <- x[[docid_field]]
     }
-    
-    corpus(x[, text_field], 
+
+    corpus(x[[text_field]],
            docvars = x[, match(c(text_field, docid_field), names(x)) * -1, drop = FALSE],
-           docnames = docname, 
+           docnames = docname,
            metacorpus = metacorpus, compress = compress)
 }
 
@@ -291,12 +292,12 @@ corpus.data.frame <- function(x, docid_field = NULL, text_field = "text", metaco
 corpus.kwic <- function(x, ...) {
     if (length(addedArgs <- list(...)))
         warning("Argument", ifelse(length(addedArgs)>1, "s ", " "), names(addedArgs), " not used.", sep = "")
-    
+
     class(x) <- "data.frame"
-    
+
     # convert docnames to a factor, as in original kwic
     x$docname <- factor(x$docname)
-    
+
     pre <- corpus(x[,c("docname", "from", "to", "pre", "keyword")], text_field = "pre")
     docvars(pre, 'context') <- "pre"
     docnames(pre) <- paste0(docnames(pre), ".pre")
@@ -304,9 +305,9 @@ corpus.kwic <- function(x, ...) {
     post <- corpus(x[,c("docname", "from", "to", "post", "keyword")], text_field = "post")
     docvars(post, 'context') <- "post"
     docnames(post) <- paste0(docnames(post), ".post")
-    
+
     result <- pre + post
-    metacorpus(result, "source") <- paste0("Corpus created from kwic(x, keywords = \"", 
+    metacorpus(result, "source") <- paste0("Corpus created from kwic(x, keywords = \"",
                                            paste(attr(x, "keywords"), collapse = ", "),
                                            "\")")
     return(result)
@@ -318,17 +319,17 @@ corpus.kwic <- function(x, ...) {
 #' @importFrom lubridate is.POSIXlt
 #' @export
 corpus.Corpus <- function(x, metacorpus = NULL, compress = FALSE, ...) {
-    
+
     if (length(addedArgs <- list(...)))
         warning("Argument", ifelse(length(addedArgs)>1, "s ", " "), names(addedArgs), " not used.", sep = "")
-    
+
     # special handling for VCorpus meta-data
     if (inherits(x, what = "VCorpus")) {
         # remove the classes that mess parsing this list
         x <- unclass(x)
         x <- lapply(x, unclass)
         x$content <- lapply(x$content, unclass)
-        
+
         # texts and associated docvars
         if (is.data.frame(x$content[[1]][["content"]])) {
             df <- as.data.frame(data.table::rbindlist(lapply(x$content, "[[", "content"), fill = TRUE))
@@ -342,7 +343,7 @@ corpus.Corpus <- function(x, metacorpus = NULL, compress = FALSE, ...) {
             doc_lengths <- 1
             df <- data.frame(text = texts, stringsAsFactors = FALSE, row.names = names_tmCorpus(x))
         }
-        
+
         # document-level metadata
         metad <- unclass(lapply(x$content, "[[", "meta"))
         # flatten any elements that are themselves lists, into pasted vectors
@@ -352,7 +353,7 @@ corpus.Corpus <- function(x, metacorpus = NULL, compress = FALSE, ...) {
         metad <- data.table::rbindlist(metad, fill = TRUE)
         # add metad to df, where meta is repeated as appropriate for content
         df <- cbind(df, metad[rep(seq_len(nrow(metad)), times = doc_lengths), ])
-        
+
     } else if (inherits(x, what = "SimpleCorpus")) {
         df <- data.frame(text = as.character(x$content), stringsAsFactors = FALSE,
                          row.names = names(x$content))
@@ -360,12 +361,12 @@ corpus.Corpus <- function(x, metacorpus = NULL, compress = FALSE, ...) {
     } else {
         stop("Cannot construct a corpus from this tm ", class(x)[1], " object")
     }
-    
+
     # corpus-level meta-data
     if (is.null(metacorpus)) metacorpus <- x$meta
-    metacorpus <- c(metacorpus, 
+    metacorpus <- c(metacorpus,
                     list(source = paste("Converted from tm Corpus \'", as.character(match.call())[2], "\'", sep="")))
-    
+
     corpus(df, metacorpus = metacorpus, compress = compress)
 }
 
