@@ -4,153 +4,107 @@
 ## Ken Benoit
 ####################################################################
 
-setClassUnion("dframe", members = c("data.frame", "NULL"))
+setClassUnion("dframe", members = c("data.frame", "NULL")) # TODO should not allow docvars to be NULL
 
 #' Virtual class "dfm" for a document-feature matrix
 #' 
-#' @description The dfm class of object is a type of \link[Matrix]{Matrix-class}
-#'   object with additional slots, described below.  \pkg{quanteda} uses two 
-#'   subclasses of the \code{dfm} class, depending on whether the object can be 
-#'   represented by a sparse matrix, in which case it is a \code{dfmSparse} 
-#'   class object, or if dense, then a \code{dfmDense} object.  See Details.
-#'   
+#' The dfm class of object is a type of \link[Matrix]{Matrix-class} object with 
+#' additional slots, described below.  \pkg{quanteda} uses two subclasses of the
+#' \code{dfm} class, depending on whether the object can be represented by a 
+#' sparse matrix, in which case it is a \code{dfm} class object, or if dense, 
+#' then a \code{dfmDense} object.  See Details.
+#' 
 #' @slot settings settings that govern corpus handling and subsequent downstream
 #'   operations, including the settings used to clean and tokenize the texts, 
 #'   and to create the dfm.  See \code{\link{settings}}.
-#' @slot weighting the feature weighting applied to the dfm.  Default is
-#'   \code{"frequency"}, indicating that the values in the cells of the dfm are
-#'   simple feature counts.  To change this, use the \code{\link{weight}}
+#' @slot weighting the feature weighting applied to the dfm.  Default is 
+#'   \code{"frequency"}, indicating that the values in the cells of the dfm are 
+#'   simple feature counts. To change this, use the \code{\link{dfm_weight}} 
 #'   method.
 #' @slot smooth a smoothing parameter, defaults to zero.  Can be changed using 
-#'   either the \code{\link{smooth}} or the \code{\link{weight}} methods.
+#'   either the \code{\link{smooth}} or the \code{\link{dfm_weight}} methods.
 #' @slot Dimnames  These are inherited from \link[Matrix]{Matrix-class} but are 
 #'   named \code{docs} and \code{features} respectively.
-#' @details The \code{dfm} class is a virtual class that will contain one of two
-#'   subclasses for containing the cell counts of document-feature matrixes: 
-#'   \code{dfmSparse} or \code{dfmDense}.
+#' @details The \code{dfm} class is a virtual class that will contain 
+#'   \link[Matrix]{dgCMatrix-class}.
 #' @seealso \link{dfm}
-#' @export
-#' @import methods
-#' @docType class
 #' @name dfm-class
+#' @rdname dfm-class
+#' @import methods
 #' @keywords internal dfm
 setClass("dfm",
-         slots = c(settings = "list", weightTf = "list", weightDf = "list", smooth = "numeric",
-                   ngrams = "integer", skip = "integer", concatenator = "character", 
+         slots = c(settings = "list", weightTf = "list", weightDf = "list", smooth = "numeric", # TODO stop using camel-case
+                   ngrams = "integer", skip = "integer", concatenator = "character", version = "integer",
                    docvars = "dframe"),
          prototype = list(settings = list(NULL),
                           Dim = integer(2), 
-                          Dimnames = list(docs=NULL, features=NULL),
+                          Dimnames = list(docs = NULL, features = NULL),
                           weightTf = list(scheme = "count", base = NULL, K = NULL),
                           weightDf = list(scheme = "unary", base = NULL, c = NULL, smoothing = NULL, threshold = NULL),
                           smooth = 0,
                           ngrams = 1L,
                           skip = 0L,
+                          version = unlist(packageVersion("quanteda")),
                           concatenator = ""),
-         contains = "Matrix")
+         contains = "dgCMatrix")
 
+# deprecated dfmSparse class for backward compatibility
 #' @rdname dfm-class
-#' @details The \code{dfmSparse} class is a sparse matrix version of
-#'   \code{dfm-class}, inheriting \link[Matrix]{dgCMatrix-class} from the
-#'   \pkg{Matrix} package.  It is the default object type created when feature
-#'   counts are the object of interest, as typical text-based feature counts
-#'   tend contain many zeroes.  As long as subsequent transformations of the dfm
-#'   preserve cells with zero counts, the dfm should remain sparse.
-#'   
-#'   When the \pkg{Matrix} package implements sparse integer matrixes, we will
-#'   switch the default object class to this object type, as integers are 4
-#'   bytes each (compared to the current numeric double type requiring 8 bytes
-#'   per cell.)
-#' @export
-setClass("dfmSparse",
-         contains = c("dfm", "dgCMatrix"))
-
-#' @rdname dfm-class
-#' @details The \code{dfmDense} class is a sparse matrix version of \code{dfm-class}, 
-#' inheriting \link[Matrix]{dgeMatrix-class} from the \pkg{Matrix} package.  dfm objects that
-#' are converted through weighting or other transformations into cells without zeroes will 
-#' be automatically converted to the dfmDense class.  This will necessarily be a much larger sized
-#' object than one of \code{dfmSparse} class, because each cell is recorded as a numeric (double) type
-#' requiring 8 bytes of storage.
-#' @export
-setClass("dfmDense",
-         contains = c("dfm", "dgeMatrix"))
+#' @keywords internal dfm
+setClass("dfmSparse", contains = "dfm")
 
 
-# S4 Method for the S4 class dense/weighted dfm
-#' @export
-#' @rdname dfm-class
-setMethod("t", signature(x = "dfmDense"), definition = 
-              function(x) {
-                  getMethod("t", "dgeMatrix")(x)
-              }) #getMethod("t", "dgeMatrix"))
-
-
-## S4 Method for the S3 class dense dfm
+## S4 Method for the S3 class dfm
 #' @export
 #' @param x the dfm object
-#' @rdname dfm-class 
+#' @rdname dfm-class
 setMethod("t",
-          signature = (x = "dfmSparse"),
-          definition = function(x) {
-              new("dfmSparse", getMethod("t", "dgCMatrix")(x))
-          })
+          signature = (x = "dfm"),
+          function(x) as.dfm(t(as(x, "dgCMatrix"))))
 
-
-
-#' @method colSums dfmSparse
+#' @method colSums dfm
 #' @rdname dfm-class
 #' @param na.rm if \code{TRUE}, omit missing values (including \code{NaN}) from
 #'   the calculations
 #' @param dims ignored
 #' @export
 setMethod("colSums", 
-          signature = (x = "dfmSparse"),
+          signature = (x = "dfm"),
           function(x, na.rm = FALSE, dims = 1L, ...) callNextMethod())
 
-#' @method rowSums dfmSparse
+#' @method rowSums dfm
 #' @rdname dfm-class
 #' @export
 setMethod("rowSums", 
-          signature = (x = "dfmSparse"),
+          signature = (x = "dfm"),
           function(x, na.rm = FALSE, dims = 1L, ...) callNextMethod())
 
 
-#' @method colMeans dfmSparse
+#' @method colMeans dfm
 #' @rdname dfm-class
 #' @export
 setMethod("colMeans", 
-          signature = (x = "dfmSparse"),
+          signature = (x = "dfm"),
           function(x, na.rm = FALSE, dims = 1L, ...) callNextMethod())
 
-#' @method rowSums dfmSparse
+#' @method rowSums dfm
 #' @rdname dfm-class
 #' @export
 setMethod("rowMeans", 
-          signature = (x = "dfmSparse"),
+          signature = (x = "dfm"),
           function(x, na.rm = FALSE, dims = 1L, ...) callNextMethod())
 
 #' @param e1 first quantity in "+" operation for dfm
 #' @param e2 second quantity in "+" operation for dfm
 #' @rdname dfm-class
-setMethod("+", signature(e1 = "dfmSparse", e2 = "numeric"),
+setMethod("+", signature(e1 = "dfm", e2 = "numeric"),
           function(e1, e2) {
-              as(as(e1, "Matrix") + e2, ifelse(e2==0, "dfmSparse", "dfmDense"))
-          })       
-#' @rdname dfm-class
-setMethod("+", signature(e1 = "numeric", e2 = "dfmSparse"),
-          function(e1, e2) {
-              as(e1 + as(e2, "Matrix"), ifelse(e1==0, "dfmSparse", "dfmDense"))
-          })  
-#' @rdname dfm-class
-setMethod("+", signature(e1 = "dfmDense", e2 = "numeric"),
-          function(e1, e2) {
-              as(as(e1, "Matrix") + e2, "dfmDense")
+              as.dfm(as(e1, "dgCMatrix") + e2)
           })
 #' @rdname dfm-class
-setMethod("+", signature(e1 = "numeric", e2 = "dfmDense"),
+setMethod("+", signature(e1 = "numeric", e2 = "dfm"),
           function(e1, e2) {
-              as(e1 + as(e2, "Matrix"), "dfmDense")
+              as.dfm(e1 + as(e2, "dgCMatrix"))
           })
 
 
@@ -188,7 +142,7 @@ as.matrix.dfm <- function(x, ...) {
 as.data.frame.dfm <- function(x, row.names = NULL, ...) {
     as.data.frame(as.matrix(x), row.names = row.names, ...)
 }
-    
+
 
 
 #' Combine dfm objects by Rows or Columns
@@ -225,6 +179,7 @@ cbind.dfm <- function(...) {
     names <- names(args) # for non-dfm objects
     
     if (!any(sapply(args, is.dfm))) stop("at least one input object must be a dfm")
+
     if (length(args) == 1) return(args[[1]])
     
     x <- args[[1]]
@@ -249,7 +204,7 @@ cbind.dfm <- function(...) {
     if (any(docnames(x) != docnames(y)))
         warning("cbinding dfms with different docnames", noBreaks. = TRUE, call. = FALSE)
     
-    result <-  new("dfmSparse", Matrix::cbind2(x, y))
+    result <-  new("dfm", Matrix::cbind2(x, y))
     if (length(args) > 2) {
         for (i in seq(3, length(args))) {
             result <- cbind(result, args[[i]])
@@ -267,6 +222,7 @@ cbind.dfm <- function(...) {
     names(dimnames(result)) <- c("docs", "features") # TODO could be removed after upgrading as.dfm()
     slots(result) <- attrs
     return(result)
+
 }
 
 
@@ -298,11 +254,8 @@ rbind.dfm <- function(...) {
     
     if (!is.dfm(x) || !is.dfm(y)) stop("all arguments must be dfm objects")
     
-    # make features identical using a null dfm
-    z <- make_null_dfm(union(featnames(x), featnames(y)))
-    x <- dfm_select(x, pattern = z, verbose = FALSE)
-    y <- dfm_select(y, pattern = z, verbose = FALSE)
-    result <-  new("dfmSparse", Matrix::rbind2(x, y))
+    feature <- union(featnames(x), featnames(y))
+    result <- new("dfm", Matrix::rbind2(pad_dfm(x, feature), pad_dfm(y, feature)))
     if (length(args) > 2) {
         for (i in seq(3, length(args))) {
             result <- rbind(result, args[[i]])
