@@ -11,7 +11,7 @@
 #' @slot weights context weighting for distance from target feature, equal in length to \code{window}
 #' @slot tri whether the lower triangle of the symmetric \eqn{V \times V} matrix is recorded
 #' @slot ordered whether a term appears before or after the target feature 
-#'      are counted seperately
+#'      are counted separately
 #' @seealso \link{fcm}
 #' @export
 #' @import methods
@@ -21,9 +21,9 @@
 setClass("fcm",
          slots = c(context = "character", window = "integer", count = "character", weights = "numeric", ordered = "logical", tri = "logical"),
          # prototype = list(Dimnames = list(contexts = NULL, features = NULL)),
+         #contains = c("dfm", "dgCMatrix", "dtCMatrix"))
          contains = c("dfm", "dgCMatrix"))
 
-
 #' create a feature co-occurrence matrix
 #' 
 #' Create a sparse feature co-occurrence matrix, measuring co-occurrences of
@@ -35,7 +35,7 @@ setClass("fcm",
 #' @param context the context in which to consider term co-occurrence: 
 #'   \code{"document"} for co-occurrence counts within document; \code{"window"}
 #'   for co-occurrence within a defined window of words, which requires a 
-#'   postive integer value for \code{window}.  Note: if \code{x} is a dfm object, then
+#'   positive integer value for \code{window}.  Note: if \code{x} is a dfm object, then
 #'   \code{context} can only be \code{"document"}.
 #' @param window positive integer value for the size of a window on either side 
 #'   of the target feature, default is 5, meaning 5 words before and after the 
@@ -52,7 +52,7 @@ setClass("fcm",
 #'   \code{1:window}, strictly decreasing by default; can be a custom-defined vector of the same length as 
 #'   \code{length(weights)}
 #' @param ordered if \code{TRUE} the number of times that a term appears before or after the target feature 
-#'      are counted seperately. Only makes sense for context = "window".
+#'      are counted separately. Only makes sense for context = "window".
 #' @param span_sentence if \code{FALSE}, then word windows will not span 
 #'   sentences
 #' @param tri if \code{TRUE} return only upper triangle (including diagonal)
@@ -65,7 +65,7 @@ setClass("fcm",
 #'   implementation of a "context-feature" matrix, consisting of a count of
 #'   feature co-occurrence within a defined context.  This context, following
 #'   Momtazi et. al. (2010), can be defined as the \emph{document},
-#'   \emph{sentences} within documents, \emph{syntactic relationships} beteeen
+#'   \emph{sentences} within documents, \emph{syntactic relationships} between
 #'   features (nouns within a sentence, for instance), or according to a
 #'   \emph{window}.  When the context is a window, a weighting function is
 #'   typically applied that is a function of distance from the target word (see
@@ -149,12 +149,13 @@ fcm.corpus <- function(x, ...) {
 #' @import Matrix
 #' @export
 fcm.dfm <- function(x, context = c("document", "window"), 
-                               count = c("frequency", "boolean", "weighted"),
-                               window = 5L,
-                               weights = 1L,
-                               ordered = FALSE,
-                               span_sentence = TRUE, tri = TRUE, ...) {
-
+                       count = c("frequency", "boolean", "weighted"),
+                       window = 5L,
+                       weights = 1L,
+                       ordered = FALSE,
+                       span_sentence = TRUE, tri = TRUE, ...) {
+    
+    x <- as.dfm(x)
     context <- match.arg(context)
     count <- match.arg(count)
     window <- as.integer(window)
@@ -189,9 +190,8 @@ fcm.dfm <- function(x, context = c("document", "window"),
     result <- result[rownames(result), colnames(result)]
     
     # discard the lower diagonal if tri == TRUE
-    if (tri) 
-        result <- Matrix::triu(result)
-    
+    if (tri) result <- Matrix::triu(result)
+
     # create a new feature context matrix
     result <- new("fcm", as(result, "dgCMatrix"), count = count,
                   context = context, window = window, weights = weights, tri = tri)
@@ -205,7 +205,7 @@ fcm.dfm <- function(x, context = c("document", "window"),
 #' @import data.table
 #' @import Matrix
 #' @export
-fcm.tokenizedTexts <- function(x, context = c("document", "window"), 
+fcm.tokens <- function(x, context = c("document", "window"), 
                        count = c("frequency", "boolean", "weighted"),
                        window = 5L,
                        weights = 1L,
@@ -213,23 +213,18 @@ fcm.tokenizedTexts <- function(x, context = c("document", "window"),
                        span_sentence = TRUE, tri = TRUE, ...) {
     context <- match.arg(context)
     count <- match.arg(count)
-    feature <- V1 <- NULL  # to avoid no visible binding errors in CHECK
-    # could add a warning if not roundly coerced to integer
-    window <- as.integer(window)
+    window <- as.integer(window) # TODO could add a warning if not roundly coerced to integer
     
     if (!span_sentence) 
         warning("spanSentence = FALSE not yet implemented")
     
-    if (context == "document") {
-        result <- fcm(dfm(x, tolower = FALSE, verbose = FALSE),
-                      count = count, tri = tri)
-    }
+    if (context == "document")
+        result <- fcm(dfm(x, tolower = FALSE, verbose = FALSE), count = count, tri = tri)
         
     if (context == "window") { 
         try (if (window < 2) stop("The window size is too small.")) 
-            
         if (count == "weighted") {
-            if (!missing(weights) & length(weights) != window) {
+            if (!missing(weights) && length(weights) != window) {
                 warning ("weights length is not equal to the window size, weights are assigned by default!")
                 weights <- 1
             }
@@ -243,9 +238,8 @@ fcm.tokenizedTexts <- function(x, context = c("document", "window"),
     }
 
     # discard the lower diagonal if tri == TRUE
-    if (tri) # & !is.tokens(x))
-        result <- Matrix::triu(result)
-
+    if (tri) result <- Matrix::triu(result)
+    
     # create a new feature context matrix
     result <- new("fcm", as(result, "dgCMatrix"), count = count,
                   context = context, window = window, weights = weights, tri = tri)
@@ -254,35 +248,41 @@ fcm.tokenizedTexts <- function(x, context = c("document", "window"),
     result
 }     
 
-
 #' @rdname print.dfm
 #' @export
 setMethod("print", signature(x = "fcm"), 
-          function(x, show.values = FALSE, show.settings = FALSE, show.summary = TRUE, nfeature = 20L, ...) {
-              ndoc <- nfeature
+          function(x, show.values = NULL, show.settings = FALSE, show.summary = TRUE, 
+                   ndoc = quanteda_options("print_dfm_max_ndoc"), 
+                   nfeature = quanteda_options("print_dfm_max_nfeature"), ...) {
               if (show.summary) {
                   cat("Feature co-occurrence matrix of: ",
                       format(ndoc(x), big.mark = ","), " by ",
-                      # ifelse(ndoc(x) > 1 | ndoc(x) == 0, "s, ", ", "),
                       format(nfeature(x), big.mark = ","), " feature",
                       if (nfeature(x) != 1L) "s" else "",
                       if (is.resampled(x)) paste(", ", nresample(x), " resamples", sep = "") else "",
                       ".\n", sep = "")
               }
-              if (show.settings) {
-                  cat("Settings: TO BE IMPLEMENTED.")
-              }
-              if (show.values | (nrow(x) <= ndoc & ncol(x) <= nfeature)) {
-                  Matrix::printSpMatrix2(x[1:min(ndoc, ndoc(x)), 1:min(nfeature, nfeature(x))], 
-                                         col.names = TRUE, 
-                                         zero.print = if (x@tri) "." else 0, ...)
-              }
+              print_dfm(x, ndoc, nfeature, show.values, show.settings, ...)
           })
 
 #' @rdname print.dfm
 #' @export
 setMethod("show", signature(object = "fcm"), function(object) print(object))
 
+#' @rdname print.dfm
+#' @method head fcm
+#' @export
+head.fcm <- function(x, n = 6L, nfeature = 6L, ...) {
+    head.dfm(x, n, nfeature, ...)
+}
+
+#' @rdname print.dfm
+#' @method tail fcm
+#' @export
+tail.fcm <- function(x, n = 6L, nfeature = 6L, ...) {
+    head.dfm(x, n, nfeature, ...)
+}
+
 #' @noRd
 #' @rdname fcm-class
 #' @export
