@@ -13,7 +13,7 @@
 #'   
 #'   The \code{"Chisquared2"} metric is the "Quadratic-Chi" measure from Pele,
 #'   O., & Werman, M. (2010). 
-#'   "\href{http://www.ariel.ac.il/sites/ofirpele/publications/ECCV2010.pdf}{The
+#'   "\href{https://link.springer.com/chapter/10.1007/978-3-642-15552-9_54}{The
 #'   Quadratic-Chi Histogram Distance Family}". In \emph{Computer Vision – ECCV
 #'   2010} (Vol. 6312, pp. 749–762). Berlin, Heidelberg: Springer, Berlin,
 #'   Heidelberg. doi.org/10.1007/978-3-642-15552-9_54.
@@ -57,6 +57,8 @@ textstat_dist.dfm <- function(x, selection = NULL,
                           margin = c("documents", "features"),
                           method = "euclidean",
                           upper = FALSE, diag = FALSE, p = 2) {
+    
+    x <- as.dfm(x)
     margin <- match.arg(margin)
     
     if (!is.null(selection)) {
@@ -202,7 +204,7 @@ as.dist.dist <- function(m, diag = FALSE, upper = FALSE) {
 
 #' coerce a dist_selection object into a list
 #' 
-#' Coerce a dist_selection matrix into a list of selected terms and tarhet terms in
+#' Coerce a dist_selection matrix into a list of selected terms and target terms in
 #' descending order.  Can be used after calling \code{\link{textstat_simil}} or
 #' \code{\link{textstat_dist}} when selection is not NULL
 #' @param x dist_selection class object
