@@ -77,7 +77,7 @@
 #'   evaluation. \emph{Language Testing}, 24(4), 459--488.
 #'   
 #'   McCarthy, P.M. & Jarvis, S. (2010). MTLD, vocd-D, and HD-D: A validation 
-#'   study of sophisticated approaces to lexical diversity assessment. 
+#'   study of sophisticated approaches to lexical diversity assessment. 
 #'   \emph{Behaviour Research Methods}, 42(2), 381--392.
 #'   
 #'   Michalke, Meik.  (2014) \emph{koRpus: An R Package for Text Analysis}. 
@@ -98,20 +98,21 @@
 #' textstat_lexdiv(mydfm, "TTR", drop = TRUE)
 #' textstat_lexdiv(mydfm, "TTR", drop = FALSE)
 textstat_lexdiv <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "U", "S", "Maas"), 
-                   log.base = 10, drop = TRUE, ...) {
+                            log.base = 10, drop = TRUE, ...) {
     UseMethod("textstat_lexdiv")
 }
-    
-    
+
+
 #' @noRd
 #' @export
 textstat_lexdiv.dfm <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "U", "S", "Maas"), 
-                           log.base = 10, drop = TRUE, ...) {
-
+                                log.base = 10, drop = TRUE, ...) {
+    
+    x <- as.dfm(x)
     addedArgs <- names(list(...))
     if (length(addedArgs))
         warning("Argument", if (length(addedArgs) > 1L) "s " else " ", addedArgs, " not used.", sep = "", noBreaks. = TRUE)
-
+    
     TTR <- C <- R <- CTTR <- U <- S <- Maas <- lgV0 <- lgeV0 <- NULL
     
     
