@@ -13,13 +13,18 @@
 tokens_group <- function(x, groups = NULL) {
     attrs <- attributes(x)
     groups <- generate_groups(x, groups)
-    groups_index <- rep(groups, lengths(x))
-    result <- structure(base::split(unlist(unclass(x), use.names = FALSE), 
-                                    factor(groups_index, levels = unique(groups))),
-                        class = c('tokens', 'tokenizedTexts'))
-    docvars(result) <- data.frame(row.names = docnames(result))
-    attributes(result, FALSE) <- attrs
-    return(result)
+    groups_unique <- unique(groups)
+    if (length(groups_unique) > 1) {
+        x <- base::split(unlist(unclass(x), use.names = FALSE), 
+                         rep(factor(groups, levels = groups_unique), lengths(x)))
+    } else {
+        x <- list(unlist(unclass(x), use.names = FALSE))
+        names(x) <- as.character(groups[1])
+    }
+    x <- structure(x, class = 'tokens')
+    docvars(x) <- data.frame(row.names = docnames(x))
+    attributes(x, FALSE) <- attrs
+    return(x)
 }
 
 # internal function to generate a grouping vector from docvars
@@ -31,5 +36,5 @@ generate_groups <- function(x, groups) {
         if (length(groups) != ndoc(x))
             stop("groups must name docvars or provide data matching the documents in x")
     }
-    groups
-}
\ No newline at end of file
+    return(groups)
+}
