@@ -146,7 +146,7 @@ textplot_wordcloud(mydfm, min.freq = 6, random.order = FALSE,
 byPartyDfm <- dfm(data_corpus_irishbudget2010, groups = "party", remove = stopwords("english"), remove_punct = TRUE)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-sort(byPartyDfm)[, 1:10]
+dfm_sort(byPartyDfm)[, 1:10]
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 recentCorpus <- corpus_subset(data_corpus_inaugural, Year > 1991)
@@ -195,7 +195,7 @@ lapply(as.list(sim), head, 10)
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # make prettier document names
 ieDfm <- dfm(data_corpus_irishbudget2010)
-textmodel(ieDfm, model = "wordfish", dir = c(2, 1))
+textmodel_wordfish(ieDfm, dir = c(2, 1))
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 quantdfm <- dfm(data_corpus_irishbudget2010, 
