@@ -1,5 +1,4 @@
-#include <RcppArmadillo.h>
-#include <RcppParallel.h>
+#include "armadillo.h"
 #include "quanteda.h"
 using namespace quanteda;
 using std::pow;
